"use strict";

require('../../mocha-config');

var Annotation = require('../../../../main/js/map/data/Annotation');
var Chemical = require('../../../../main/js/map/data/Chemical');
var ChemicalPanel = require('../../../../main/js/gui/leftPanel/ChemicalPanel');
var PanelControlElementType = require('../../../../main/js/gui/PanelControlElementType');
var ServerConnector = require('../../ServerConnector-mock');

var chai = require('chai');
var assert = chai.assert;
var logger = require('../../logger');

describe('ChemicalPanel', function () {
  function createPanel(){
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    helper.createChemicalDbOverlay(map);

    return new ChemicalPanel({
      element: testDiv,
      customMap: map
    });
  }

  describe('constructor', function () {
    it('default', function () {
      var map = helper.createCustomMap();
      helper.createChemicalDbOverlay(map);

      var panel = new ChemicalPanel({
        element: testDiv,
        customMap: map
      });
      assert.equal(logger.getWarnings().length, 0);
      assert.ok(panel.isDisabled());
    });
    it('map with disease', function () {
      return ServerConnector.getProject().then(function (project) {
        project.setDisease(new Annotation({
          link: "http://bioportal.bioontology.org/ontologies/1351?p=terms&conceptid=D010300",
          type: "MESH_2012",
          resource: "D010300"
        }));

        var map = helper.createCustomMap(project);
        helper.createChemicalDbOverlay(map);

        var panel = new ChemicalPanel({
          element: testDiv,
          customMap: map
        });
        assert.equal(logger.getWarnings().length, 0);
        assert.notOk(panel.isDisabled());
      });
    });
  });

  describe('createPreamble', function () {
    it('default', function () {
      var map = helper.createCustomMap();
      helper.createChemicalDbOverlay(map);

      var panel = new ChemicalPanel({
        element: testDiv,
        customMap: map
      });

      assert.ok(panel.createPreamble().innerHTML.indexOf("NOT FOUND") > 0);
    });

    it('for empty', function () {
      var map = helper.createCustomMap();
      helper.createChemicalDbOverlay(map);

      var panel = new ChemicalPanel({
        element: testDiv,
        customMap: map
      });

      assert.ok(panel.createPreamble(new Chemical()).innerHTML.indexOf("NOT FOUND") > 0);
    });
  });

  it('on searchResults changed', function () {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    var chemicalDbOverlay = helper.createChemicalDbOverlay(map);

    new ChemicalPanel({
      element: testDiv,
      customMap: map
    });

    return chemicalDbOverlay.searchByQuery("rotenone").then(function () {
      assert.equal(logger.getWarnings().length, 1);
      assert.ok(testDiv.innerHTML.indexOf("marker/mechanism") >= 0);
    });
  });

  it('searchByQuery', function () {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    helper.createChemicalDbOverlay(map);

    var panel = new ChemicalPanel({
      element: testDiv,
      customMap: map
    });

    panel.getControlElement(PanelControlElementType.SEARCH_INPUT).value = "rotenone";

    return panel.searchByQuery().then(function () {
      assert.equal(logger.getWarnings().length, 1);
      assert.ok(testDiv.innerHTML.indexOf("Rotenone ") >= 0);
    });
  });

  it("refreshSearchAutocomplete", function () {
    var panel = createPanel();

    return panel.refreshSearchAutocomplete("s").then(function (data) {
      assert.ok(data);
    });
  });

});
