"use strict";

var logger = require('../../logger');

var IdentifiedElement = require('../../../../main/js/map/data/IdentifiedElement');
var ChemicalDbOverlay = require('../../../../main/js/map/overlay/ChemicalDbOverlay');

var assert = require('assert');

describe('ChemicalDbOverlay', function() {

  it("constructor 1", function() {
    var map = helper.createCustomMap();
    var oc = new ChemicalDbOverlay({
      map : map,
      name : 'chemical'
    });
    assert.ok(oc);
    assert.equal(oc.getName(), 'chemical');

    assert.equal(logger.getWarnings.length, 0);
  });

  it("searchByQuery", function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    var searchDb = helper.createChemicalDbOverlay(map);
    return searchDb.searchByQuery("rotenone").then(function(chemicals) {
      assert.equal(chemicals.length, 1);
      assert.equal(searchDb.getQueries().length, 1);
      return searchDb.getElementsByQuery(searchDb.getQueries()[0]);
    }).then(function(elements) {
      //these are targets
      assert.ok(elements.length>0);
      var chemical = elements.element;
      assert.equal(chemical.getName(), "Rotenone");
      return searchDb.getIdentifiedElements();
    }).then(function(elements) {
      assert.equal(elements.length,0);
    });
  });

  it("searchNamesByTarget", function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    var searchDb = helper.createChemicalDbOverlay(map);

    var target = new IdentifiedElement({
      type : "ALIAS",
      id : 329170,
      modelId : 15781
    });

    return searchDb.searchNamesByTarget(target).then(function(chemicalNames) {
      assert.equal(chemicalNames.length, 0);
    });
  });

});
